@@ -682,7 +682,7 @@ class ConsumerThread(Thread):
                                        virtual_host=self.amqp_credentials.vhost,
                                        ssl=self.amqp_credentials.ssl)
 
-                    self.consumer.close()
+                    #self.consumer.close()
 
                     self.consumer = Consumer(connection=self.amqpconn,
                                      queue=self.client_id + '_client_queue',
