@@ -252,7 +252,7 @@ class QAMServer:
                                        password=self.amqp_credentials.password,
                                        virtual_host=self.amqp_credentials.vhost,
                                        ssl=self.amqp_credentials.ssl)
-                self.consumer.close()
+                #self.consumer.close()
 
                 self.consumer = Consumer(connection=self.amqpconn,
                                  queue=self.server_id + '_server_queue',
